summaryrefslogtreecommitdiff
path: root/nuttx/drivers/audio
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/drivers/audio')
-rw-r--r--nuttx/drivers/audio/audio_null.c4
-rw-r--r--nuttx/drivers/audio/i2schar.c2
-rw-r--r--nuttx/drivers/audio/wm8904.c4
3 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/drivers/audio/i2schar.c b/nuttx/drivers/audio/i2schar.c
index a7a86e90f..4a12d5110 100644
--- a/nuttx/drivers/audio/i2schar.c
+++ b/nuttx/drivers/audio/i2schar.c
@@ -413,7 +413,7 @@ int i2schar_register(FAR struct i2s_dev_s *i2s, int minor)
/* Allocate a I2S character device structure */
- priv = (FAR struct i2schar_dev_s *)kzalloc(sizeof(struct i2schar_dev_s));
+ priv = (FAR struct i2schar_dev_s *)kmm_zalloc(sizeof(struct i2schar_dev_s));
if (priv)
{
/* Initialize the I2S character device structure */
diff --git a/nuttx/drivers/audio/audio_null.c b/nuttx/drivers/audio/audio_null.c
index 62ccc061f..446682486 100644
--- a/nuttx/drivers/audio/audio_null.c
+++ b/nuttx/drivers/audio/audio_null.c
@@ -831,10 +831,10 @@ FAR struct audio_lowerhalf_s *audio_null_initialize(void)
/* Allocate the null audio device structure */
- priv = (FAR struct null_dev_s *)kzalloc(sizeof(struct null_dev_s));
+ priv = (FAR struct null_dev_s *)kmm_zalloc(sizeof(struct null_dev_s));
if (priv)
{
/* Initialize the null audio device structure. Since we used kzalloc,
* only the non-zero elements of the structure need to be initialized.
*/
@@ -831,10 +831,10 @@ FAR struct audio_lowerhalf_s *audio_null_initialize(void)
if (priv)
{
- /* Initialize the null audio device structure. Since we used kzalloc,
+ /* Initialize the null audio device structure. Since we used kmm_zalloc,
* only the non-zero elements of the structure need to be initialized.
*/
diff --git a/nuttx/drivers/audio/wm8904.c b/nuttx/drivers/audio/wm8904.c
index c9e32548f..13712c051 100644
--- a/nuttx/drivers/audio/wm8904.c
+++ b/nuttx/drivers/audio/wm8904.c
@@ -2470,10 +2470,10 @@ FAR struct audio_lowerhalf_s *
/* Allocate a WM8904 device structure */
- priv = (FAR struct wm8904_dev_s *)kzalloc(sizeof(struct wm8904_dev_s));
+ priv = (FAR struct wm8904_dev_s *)kmm_zalloc(sizeof(struct wm8904_dev_s));
if (priv)
{
/* Initialize the WM8904 device structure. Since we used kzalloc,
* only the non-zero elements of the structure need to be initialized.
*/
@@ -2470,10 +2470,10 @@ FAR struct audio_lowerhalf_s *
if (priv)
{
- /* Initialize the WM8904 device structure. Since we used kzalloc,
+ /* Initialize the WM8904 device structure. Since we used kmm_zalloc,
* only the non-zero elements of the structure need to be initialized.
*/